@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -15,9 +18,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cdklabs/cdk-hyperledger-fabric-network",
-    "0.8.562",
+    "0.8.670",
     __name__[0:-6],
-    "cdk-hyperledger-fabric-network@0.8.562.jsii.tgz",
+    "cdk-hyperledger-fabric-network@0.8.670.jsii.tgz",
 )
 
 __all__ = [
